@@ -1,11 +1,11 @@
 use strict;
 use warnings;
-package Dist::Zilla::PluginBundle::Author::ETHER; # git description: v0.094-17-gb48817e
+package Dist::Zilla::PluginBundle::Author::ETHER; # git description: v0.095-7-g8837c64
 # ABSTRACT: A plugin bundle for distributions built by ETHER
 # KEYWORDS: author bundle distribution tool
 # vim: set ts=8 sts=4 sw=4 tw=78 et :
 
-our $VERSION = '0.095';
+our $VERSION = '0.096';
 
 use Moose;
 with
@@ -146,7 +146,7 @@ sub configure
     # this is better than injecting a perl prereq for 5.008, to allow MBT to
     # become more 5.006-compatible in the future without forcing the distribution to be re-released.
     die 'Module::Build::Tiny should not be used in distributions that are targeting perl 5.006!'
-        if any { $_ eq 'ModuleBuildTiny' } $self->installer
+        if any { /ModuleBuildTiny/ } $self->installer
             and (not exists $self->payload->{'Test::MinimumVersion.max_target_perl'}
                  or $self->payload->{'Test::MinimumVersion.max_target_perl'} < '5.008');
 
@@ -388,7 +388,7 @@ Dist::Zilla::PluginBundle::Author::ETHER - A plugin bundle for distributions bui
 
 =head1 VERSION
 
-version 0.095
+version 0.096
 
 =head1 SYNOPSIS
 
