@@ -4,7 +4,7 @@ package Pod::Weaver::PluginBundle::Author::ETHER;
 # ABSTRACT: A plugin bundle for pod woven by ETHER
 # vim: set ts=8 sts=4 sw=4 tw=78 et :
 
-our $VERSION = '0.095';
+our $VERSION = '0.096';
 
 use namespace::autoclean -also => ['_exp'];
 
@@ -23,7 +23,9 @@ sub configure
     return (
         '@CorePrep',
         '-SingleEncoding',
+        [ '-Transformer' => List => { transformer => 'List' } ],
 
+        [ 'Region' => 'header' ],
         'Name',
         'Version',
         [ 'Region' => 'prelude' ],
@@ -38,8 +40,7 @@ sub configure
         'Authors',
         [ 'Contributors' => { ':version' => '0.008' } ],
         'Legal',
-
-        [ '-Transformer' => List => { transformer => 'List' } ],
+        [ 'Region' => 'footer' ],
     );
 }
 
@@ -121,7 +122,7 @@ Pod::Weaver::PluginBundle::Author::ETHER - A plugin bundle for pod woven by ETHE
 
 =head1 VERSION
 
-version 0.095
+version 0.096
 
 =head1 SYNOPSIS
 
@@ -150,6 +151,10 @@ following F<weaver.ini>, minus some optimizations:
 
     [-SingleEncoding]
 
+    [-Transformer / List]
+    transformer = List
+
+    [Region / header]
     [Name]
     [Version]
 
@@ -177,32 +182,63 @@ following F<weaver.ini>, minus some optimizations:
     :version = 0.008
 
     [Legal]
-
-    [-Transformer / List]
-    transformer = List
+    [Region / footer]
 
 This is also equivalent (other than section ordering) to:
 
+    [-Transformer / List]
+    transformer = List
+
+    [Region / header]
     [@Default]
     [Contributors]
     :version = 0.008
-
-    [-Transformer / List]
-    transformer = List
+    [Region / footer]
 
 =head1 OPTIONS / OVERRIDES
 
 None at this time. (The bundle is never instantiated, so this doesn't seem to
 be possible without updates to L<Pod::Weaver>.)
 
+=head1 ADDING STOPWORDS FOR SPELLING TESTS
+
+As noted in L<Dist::Zilla::PluginBundle::Author::ETHER>, stopwords for
+spelling tests can be added by adding a directive to pod:
+
+    =for stopwords foo bar baz
+
+However, if the stopword appears in the module's abstract, it is moved to the
+C<NAME> section, which will be above your stopword directive. You can handle
+this by declaring the stopword in the special C<header> section, which will be
+woven ahead of everything else:
+
+    =for :header
+    =for stopwords foo bar baz
+
 =head1 SEE ALSO
 
 =over 4
 
+=item *
+
 L<Pod::Weaver>
+
+=item *
+
 L<Pod::Weaver::PluginBundle::Default>
+
+=item *
+
 L<Dist::Zilla::Plugin::PodWeaver>
 
+=item *
+
+L<Dist::Zilla::PluginBundle::Author::ETHER>
+
+=item *
+
+L<Dist::Zilla::MintingProfile::Author::ETHER>
+
 =back
 
 =head1 SUPPORT
